==> pyloadl-0.2.0.tar.bz2: pyloadl-0.2.0/examples/llbg/bg_machine_query.py <==
from pyloadl import *
from time import gmtime, strftime
from sys import exit

"""


"""

bg_node_card_state_t = [ "UP", "DOWN", "MISSING", "ERROR", "NAV" ]

bg_partition_state_t = [ "FREE", "CONFIGURING", "READY",
                         "BUSY", "DEALLOCATING", "ERROR",
                         "NAV" ]

bg_port_t = [ "PLUS_X", "MINUS_X", "PLUS_Y",
              "MINUS_Y", "PLUS_Z", "MINUS_Z",
              "S0", "S1", "S2", "S3", "S4", "S5",
              "NAV" ]

bg_switch_dimension_t = [ "DIM_X", "DIM_Y", "DIM_Z", "DIM_NAV" ]

bg_switch_state_t = [ "UP", "DOWN", "MISSING", "ERROR", "NAV" ]

bg_wire_state_t = [ "UP", "DOWN", "MISSING", "ERROR", "NAV" ]

# Query Blue Gene information

query = ll_query(BLUE_GENE);
if not PyCObjValid(query):
   print "ll_query(): returns NULL\n" 
   exit(-1)

retval = ll_set_request(query, QUERY_ALL, "", ALL_DATA)
if retval != 0:
   print "ll_set_request(): error %d\n" % retval
   exit(-1)

# Get the machine objects from the LoadL_negotiator (central manager) daemon

machine, obj_count, err_code = ll_get_objs(query, LL_CM, "")
if err_code != 0:
    print "Query MACHINES: ll_get_objs() returns NULL. Error code =  %d" % err_code
    exit(-1)

BP_size = ll_get_data(machine, LL_BgMachineBPSize)
print "Machine BP_size = %s %s %s\n" % (BP_size[0], BP_size[1], BP_size[2])

bp = ll_get_data(machine, LL_BgMachineSwitchCount)
count = ll_get_data(machine, LL_BgMachineWireCount)
print "BG Machine Wire Count - %s" % count
count = ll_get_data(machine, LL_BgMachinePartitionCount)
print "Base Partition Count - %s" % count

bp = ll_get_data(machine, LL_BgMachineGetFirstBP)
while PyCObjValid(bp):

    Busy = ll_get_data(bp, LL_BgBPSubDividedBusy)
    print "Base Partition Div Busy - %s" % Busy
    partition = ll_get_data(bp, LL_BgBPCurrentPartition)
    print "Base Partition Current Partition - %s" % partition
    partition_state = ll_get_data(bp, LL_BgBPCurrentPartitionState)
    print "Base Partition Current Partition State - %s" % bg_partition_state_t[partition_state]
    node_card_count = ll_get_data(bp, LL_BgBPNodeCardCount)
    print "Base Partition Node Card Count - %s" % node_card_count

    bp = ll_get_data(machine, LL_BgMachineGetNextBP)

bg_switch = ll_get_data(machine, LL_BgMachineGetFirstSwitch)
while PyCObjValid(bg_switch):
    bg_sw_id = ll_get_data(bg_switch, LL_BgSwitchId)
    print "BG Switch ID %s" % bg_sw_id
    bg_sw_pt_id = ll_get_data(bg_switch, LL_BgSwitchBasePartitionId)
    print "BG Switch Base Part ID %s" % bg_sw_pt_id
    bg_sw_state = ll_get_data(bg_switch, LL_BgSwitchState)
    print "BG Switch State %s" % bg_switch_state_t[bg_sw_state]
    bg_sw_dim = ll_get_data(bg_switch, LL_BgSwitchDimension)
    print "BG Switch Dimension %s" % bg_switch_dimension_t[bg_sw_dim]
    bg_sw_ccnt = ll_get_data(bg_switch, LL_BgSwitchConnCount)
    print "BG Switch Connection Count %s" % bg_sw_ccnt

    bg_switch_conn = ll_get_data(bg_switch, LL_BgSwitchGetFirstConn)
    while PyCObjValid(bg_switch_conn):
        bg_switch_tport = ll_get_data(bg_switch_conn, LL_BgPortConnToSwitchPort)
        bg_switch_fport = ll_get_data(bg_switch_conn, LL_BgPortConnFromSwitchPort)
        print "\tConnection: from %s to %s" % (bg_switch_tport,bg_switch_fport)
        bg_switch_conn = ll_get_data(bg_switch, LL_BgSwitchGetNextConn)

    bg_switch = ll_get_data(machine, LL_BgMachineGetNextSwitch)

bg_switch_wire = ll_get_data(machine, LL_BgMachineGetFirstWire)
while PyCObjValid(bg_switch_wire):
   wire_id = ll_get_data(bg_switch_wire, LL_BgWireId)
   wire_state = ll_get_data(bg_switch_wire, LL_BgWireState)
   wire_state = bg_wire_state_t[wire_state]
   wire_fpcompid = ll_get_data(bg_switch_wire, LL_BgWireFromPortCompId)
   wire_tpcompid = ll_get_data(bg_switch_wire, LL_BgWireToPortCompId)
   wire_tpid = ll_get_data(bg_switch_wire, LL_BgWireToPortId)
   wire_curr_part = ll_get_data(bg_switch_wire, LL_BgWireCurrentPartition)
   if wire_curr_part == "":
     wire_curr_part = "None"
   wire_curr_pstate = ll_get_data(bg_switch_wire, LL_BgWireCurrentPartitionState)
   wire_curr_pstate = bg_partition_state_t[wire_curr_pstate]
   print "Wire id=%10s   state=%s      from=%s    to=%s:%s p=%s      pstate=%s" % (wire_id, wire_state, wire_fpcompid, wire_tpcompid,wire_tpid, wire_curr_part,wire_curr_pstate)

   bg_switch_wire = ll_get_data(machine, LL_BgMachineGetNextWire)

   bg_switch = ll_get_data(machine, LL_BgMachineGetNextSwitch)

==> pyloadl-0.4.3.tar.bz2: pyloadl-0.4.3/examples/llbg/bg_machine_query.py <==
from pyloadl import *
from time import gmtime, strftime
from sys import exit

"""

  BlueGene Machine Query

"""

bg_node_card_state_t = [ "UP", "DOWN", "MISSING", "ERROR", "NAV" ]

bg_partition_state_t = [ "FREE", "CONFIGURING", "READY",
                         "BUSY", "DEALLOCATING", "ERROR",
                         "NAV" ]

bg_port_t = [ "PLUS_X", "MINUS_X", "PLUS_Y",
              "MINUS_Y", "PLUS_Z", "MINUS_Z",
              "S0", "S1", "S2", "S3", "S4", "S5",
              "NAV" ]

bg_switch_dimension_t = [ "DIM_X", "DIM_Y", "DIM_Z", "DIM_NAV" ]

bg_switch_state_t = [ "UP", "DOWN", "MISSING", "ERROR", "NAV" ]

bg_wire_state_t = [ "UP", "DOWN", "MISSING", "ERROR", "NAV" ]

# Query Blue Gene information

query = ll_query(BLUE_GENE)
if not PyCObjValid(query):
   print "ll_query(): returns NULL\n" 
   exit(-1)

retval = ll_set_request(query, QUERY_ALL, "", ALL_DATA)
if retval != 0:
   print "ll_set_request(): error %d\n" % retval
   exit(-1)

# Get the machine objects from the LoadL_negotiator (central manager) daemon

machine, obj_count, err_code = ll_get_objs(query, LL_CM, "")
if err_code != 0:
    print "Query MACHINES: ll_get_objs() returns NULL. Error code =  %d" % err_code
    exit(-1)

BP_size = ll_get_data(machine, LL_BgMachineBPSize)
print "Machine BP_size = %s %s %s\n" % (BP_size[0], BP_size[1], BP_size[2])

bp = ll_get_data(machine, LL_BgMachineSwitchCount)
count = ll_get_data(machine, LL_BgMachineWireCount)
print "BG Machine Wire Count - %s" % count
count = ll_get_data(machine, LL_BgMachinePartitionCount)
print "Base Partition Count - %s" % count

bp = ll_get_data(machine, LL_BgMachineGetFirstBP)
while PyCObjValid(bp):

    Busy = ll_get_data(bp, LL_BgBPSubDividedBusy)
    print "Base Partition Div Busy - %s" % Busy
    partition = ll_get_data(bp, LL_BgBPCurrentPartition)
    print "Base Partition Current Partition - %s" % partition
    partition_state = ll_get_data(bp, LL_BgBPCurrentPartitionState)
    print "Base Partition Current Partition State - %s" % bg_partition_state_t[partition_state]
    node_card_count = ll_get_data(bp, LL_BgBPNodeCardCount)
    print "Base Partition Node Card Count - %s" % node_card_count

    bp = ll_get_data(machine, LL_BgMachineGetNextBP)

bg_switch = ll_get_data(machine, LL_BgMachineGetFirstSwitch)
while PyCObjValid(bg_switch):
    bg_sw_id = ll_get_data(bg_switch, LL_BgSwitchId)
    print "BG Switch ID %s" % bg_sw_id
    bg_sw_pt_id = ll_get_data(bg_switch, LL_BgSwitchBasePartitionId)
    print "BG Switch Base Part ID %s" % bg_sw_pt_id
    bg_sw_state = ll_get_data(bg_switch, LL_BgSwitchState)
    print "BG Switch State %s" % bg_switch_state_t[bg_sw_state]
    bg_sw_dim = ll_get_data(bg_switch, LL_BgSwitchDimension)
    print "BG Switch Dimension %s" % bg_switch_dimension_t[bg_sw_dim]
    bg_sw_ccnt = ll_get_data(bg_switch, LL_BgSwitchConnCount)
    print "BG Switch Connection Count %s" % bg_sw_ccnt

    bg_switch_conn = ll_get_data(bg_switch, LL_BgSwitchGetFirstConn)
    while PyCObjValid(bg_switch_conn):
        bg_switch_tport = ll_get_data(bg_switch_conn, LL_BgPortConnToSwitchPort)
        bg_switch_fport = ll_get_data(bg_switch_conn, LL_BgPortConnFromSwitchPort)
        print "\tConnection: from %s to %s" % (bg_switch_tport,bg_switch_fport)
        bg_switch_conn = ll_get_data(bg_switch, LL_BgSwitchGetNextConn)

    bg_switch = ll_get_data(machine, LL_BgMachineGetNextSwitch)

bg_switch_wire = ll_get_data(machine, LL_BgMachineGetFirstWire)
while PyCObjValid(bg_switch_wire):
   wire_id = ll_get_data(bg_switch_wire, LL_BgWireId)
   wire_state = ll_get_data(bg_switch_wire, LL_BgWireState)
   wire_state = bg_wire_state_t[wire_state]
   wire_fpcompid = ll_get_data(bg_switch_wire, LL_BgWireFromPortCompId)
   wire_tpcompid = ll_get_data(bg_switch_wire, LL_BgWireToPortCompId)
   wire_tpid = ll_get_data(bg_switch_wire, LL_BgWireToPortId)
   wire_curr_part = ll_get_data(bg_switch_wire, LL_BgWireCurrentPartition)
   if wire_curr_part == "":
     wire_curr_part = "None"
   wire_curr_pstate = ll_get_data(bg_switch_wire, LL_BgWireCurrentPartitionState)
   wire_curr_pstate = bg_partition_state_t[wire_curr_pstate]
   print "Wire id=%10s   state=%s      from=%s    to=%s:%s p=%s      pstate=%s" % (wire_id, wire_state, wire_fpcompid, wire_tpcompid,wire_tpid, wire_curr_part,wire_curr_pstate)

   bg_switch_wire = ll_get_data(machine, LL_BgMachineGetNextWire)

   bg_switch = ll_get_data(machine, LL_BgMachineGetNextSwitch)
